==> hoteldruid_2.2.1.orig.tar.gz: hoteldruid/includes/lang/en/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insert the assignment rules for reservations of year"; break;
case "Regola di assegnazione":  		$messaggio = "Assignment rule"; break;
case "nel periodo dal":  			$messaggio = "in the period from"; break;
case "al":  					$messaggio = "to"; break;
case "motivazione":  				$messaggio = "motivation"; break;
case "Inserisci la regola":  			$messaggio = "Insert rule"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Insert or modify rule"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Delete all rules of this kind"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "When choosing rate"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "if no other method of assignment is inserted"; break;
case "Vedi le regole già inserite":  		$messaggio = "View already inserted rules"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Not all necessary data have been inserted"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "La regola è stata inserita":  		$messaggio = "The rule has been inserted"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Are you sure you want to delete all the rules of type 1"; break;
case "SI":  					$messaggio = "YES"; break;
case "Le regole sono state cancellate":  	$messaggio = "The rules have been deleted"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "You must choose the rate"; break;
case " non esiste":  				$messaggio = " does not exist"; break;
case "La regola di assegnazione":		$messaggio = "The assignment rule"; break;
case "è stata inserita":			$messaggio = "has been inserted"; break;
case "è stata modificata":			$messaggio = "has been modified"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Motivazione non valida":  		$messaggio = "Non valid motivation"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned user, delete the rule before inserting a new one"; break;
case "Quando l'utente amministratore":  	$messaggio = "When the administrator user"; break;
case "sceglie la tariffa":  			$messaggio = "chooses rate"; break;
case "fai risultare come se l'utente":  	$messaggio = "show as if the user"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "had inserted the reservation and the eventual client"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "You have to choose the user to be associated"; break;
case "L'utente ":  				$messaggio = "The user "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "automatically assign as number of people"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "if no other number is inserted"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned number of people, delete the rule before inserting a new one"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "You have to choose the number of people to be associated"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid_2.2.2.orig.tar.gz: hoteldruid/includes/lang/en/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insert the assignment rules for reservations of year"; break;
case "Regola di assegnazione":  		$messaggio = "Assignment rule"; break;
case "nel periodo dal":  			$messaggio = "in the period from"; break;
case "al":  					$messaggio = "to"; break;
case "motivazione":  				$messaggio = "motivation"; break;
case "Inserisci la regola":  			$messaggio = "Insert rule"; break;
case "Inserisci o modifica la regola":  	$messaggio = "Insert or modify rule"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Delete all rules of this kind"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "When choosing rate"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "if no other method of assignment is inserted"; break;
case "Vedi le regole già inserite":  		$messaggio = "View already inserted rules"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Not all necessary data have been inserted"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "La regola è stata inserita":  		$messaggio = "The rule has been inserted"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Are you sure you want to delete all the rules of type 1"; break;
case "SI":  					$messaggio = "YES"; break;
case "Le regole sono state cancellate":  	$messaggio = "The rules have been deleted"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "You must choose the rate"; break;
case " non esiste":  				$messaggio = " does not exist"; break;
case "La regola di assegnazione":		$messaggio = "The assignment rule"; break;
case "è stata inserita":			$messaggio = "has been inserted"; break;
case "è stata modificata":			$messaggio = "has been modified"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Motivazione non valida":  		$messaggio = "Non valid motivation"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned user, delete the rule before inserting a new one"; break;
case "Quando l'utente amministratore":  	$messaggio = "When the administrator user"; break;
case "sceglie la tariffa":  			$messaggio = "chooses rate"; break;
case "fai risultare come se l'utente":  	$messaggio = "show as if the user"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "had inserted the reservation and the eventual client"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "You have to choose the user to be associated"; break;
case "L'utente ":  				$messaggio = "The user "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "automatically assign as number of people"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "if no other number is inserted"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen rate has already an assigned number of people, delete the rule before inserting a new one"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "You have to choose the number of people to be associated"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
